@@ -1,5 +1,3 @@
-var config_reader = require('./config_reader.js');
-var config_seeder = require('./config_seeder.js')
 var logger = require('./logging.js');
 
 var fs = require('fs');
@@ -64,6 +62,9 @@ for (var i=2; i<process.argv.length; ++i) {
   }
 }
 
+var config_reader = require('./config_reader.js');
+var config_seeder = require('./config_seeder.js');
+
 if (global.config_file) {
   config_seeder.set(global.config_key, global.config_file, function(err) {
     if (err) {
